==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/emoticons/translations/emoticons_ca@valencia.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca@valencia">
<context>
    <name>@default</name>
    <message>
        <source>default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Look</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Icons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Emoticons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable emoticons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Animate emoticons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Icon theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose emoticons theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Install new emoticons...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EmoticonsConfigurationUiHandler</name>
    <message>
        <source>Open icon theme archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Installation failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Archive (*.tar.xz *.tar.gz *.tar.bz2 *.tar *.zip)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>InsertEmoticonAction</name>
    <message>
        <source>Insert Emoticon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insert emoticon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insert emoticon - enable in configuration</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/emoticons/translations/emoticons_ca@valencia.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ca@valencia" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>default</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Look</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Icons</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Emoticons</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable emoticons</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Animate emoticons</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Icon theme</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Choose emoticons theme</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Install new emoticons...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>EmoticonsConfigurationUiHandler</name>
    <message>
        <source>Open icon theme archive</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Installation failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Archive (*.tar.xz *.tar.gz *.tar.bz2 *.tar *.zip)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>InsertEmoticonAction</name>
    <message>
        <source>Insert Emoticon</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Insert emoticon</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Insert emoticon - enable in configuration</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
